@@ -4,7 +4,7 @@ use MooseX::MethodAttributes::Role;
 use namespace::autoclean;
 use JSON::Any;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has _authkeys => (
     init_arg => 'authkeys', isa => 'HashRef',
@@ -67,7 +67,7 @@ sub prepare_api_request : Private {
 sub return_api_data : Private {
      my ( $self, $c ) = @_;
     $c->response->header('Cache-Control' => 'no-cache');
-    $c->response->header('application/json');
+    $c->response->content_type('application/json');
     my $jsonobject = JSON::Any->new;
     my $responsetext = $jsonobject->encode($c->stash->{'api_response'});
     $c->response->body($responsetext);
